pub struct WinitWindowBuilder { /* private fields */ }Expand description
A builder for creating WinitWindow instances.
This follows the builder pattern to provide an ergonomic API for window creation.
Implementations
Sourceimpl WinitWindowBuilder
impl WinitWindowBuilder
Sourcepub fn with_title(self, title: impl Into<String>) -> Self
pub fn with_title(self, title: impl Into<String>) -> Self
Sets the title of the window to be built.
Sourcepub fn with_dimensions(self, width: u32, height: u32) -> Self
pub fn with_dimensions(self, width: u32, height: u32) -> Self
Sets the initial inner dimensions of the window to be built.
Sourcepub fn build(self, event_loop: &ActiveEventLoop) -> Result<WinitWindow, OsError>
pub fn build(self, event_loop: &ActiveEventLoop) -> Result<WinitWindow, OsError>
Builds the WinitWindow using the provided winit event loop.
Errors
Returns an OsError if the underlying winit window creation fails.