Struct TextureAtlas
pub struct TextureAtlas { /* private fields */ }Expand description
A dynamic texture atlas that manages allocation and GPU updates.
Implementations
impl TextureAtlas
impl TextureAtlas
pub fn new(
device: &(dyn GraphicsDevice + 'static),
size: u32,
format: TextureFormat,
label: &str,
) -> Result<TextureAtlas, Box<dyn Error + Send + Sync>>
pub fn new( device: &(dyn GraphicsDevice + 'static), size: u32, format: TextureFormat, label: &str, ) -> Result<TextureAtlas, Box<dyn Error + Send + Sync>>
Creates a new texture atlas with the specified size.
pub fn allocate_and_upload(
&mut self,
device: &(dyn GraphicsDevice + 'static),
width: u32,
height: u32,
pixels: &[u8],
bytes_per_pixel: u32,
) -> Option<AtlasRect>
pub fn allocate_and_upload( &mut self, device: &(dyn GraphicsDevice + 'static), width: u32, height: u32, pixels: &[u8], bytes_per_pixel: u32, ) -> Option<AtlasRect>
Allocates space for a sub-texture and uploads data to the GPU.
pub fn texture(&self) -> TextureId
pub fn texture(&self) -> TextureId
Returns the texture handle that stores the atlas pixels.
pub fn view(&self) -> TextureViewId
pub fn view(&self) -> TextureViewId
Returns the texture view used to sample the atlas.