pub struct EguiWgpuRenderer { /* private fields */ }Expand description
Custom wgpu renderer for egui primitives.
Implementations
Sourceimpl EguiWgpuRenderer
impl EguiWgpuRenderer
Sourcepub fn initialize(&mut self, device: &Device, shader_source: &str)
pub fn initialize(&mut self, device: &Device, shader_source: &str)
Initializes the render pipeline and bind group layouts.
Must be called once with the wgpu device before any rendering.
Sourcepub fn update_textures(
&mut self,
device: &Device,
queue: &Queue,
textures_delta: &TexturesDelta,
)
pub fn update_textures( &mut self, device: &Device, queue: &Queue, textures_delta: &TexturesDelta, )
Updates textures from egui’s [TexturesDelta].
Sourcepub fn register_external_texture(
&mut self,
device: &Device,
view: &TextureView,
) -> TextureId
pub fn register_external_texture( &mut self, device: &Device, view: &TextureView, ) -> TextureId
Registers an externally-created wgpu texture view (e.g. an offscreen viewport render target) as an egui-managed texture.
Returns the [TextureId] that can be used in egui Image widgets.
Sourcepub fn update_external_texture(
&mut self,
device: &Device,
id: TextureId,
view: &TextureView,
)
pub fn update_external_texture( &mut self, device: &Device, id: TextureId, view: &TextureView, )
Updates the wgpu texture view backing an existing external texture.
Call this when the offscreen render target is resized.
Sourcepub fn render(
&self,
state: &mut EguiRenderState<'_>,
clipped_primitives: &[ClippedPrimitive],
pixels_per_point: f32,
)
pub fn render( &self, state: &mut EguiRenderState<'_>, clipped_primitives: &[ClippedPrimitive], pixels_per_point: f32, )
Renders the egui output.