pub struct WgpuRenderSystem { /* private fields */ }Expand description
The concrete, WGPU-based implementation of the RenderSystem trait.
This struct encapsulates all the state necessary to drive rendering with WGPU, including the graphics context, the logical device, GPU profiler, and complex state for handling window resizing gracefully.
It acts as the primary rendering backend for the engine when the WGPU feature is enabled.
Implementations
Sourceimpl WgpuRenderSystem
impl WgpuRenderSystem
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new, uninitialized WgpuRenderSystem.
The system is not usable until RenderSystem::init is called.